#pragma once

namespace ziapi {

/**
 *  Semantic versioning structure with a major and a minor version
 */
struct Version {
    Version(int major, int minor) : major(major), minor(minor) {}

    inline bool operator==(const Version &other) const noexcept
    {
        return major == other.major && minor == other.minor;
    }

    inline bool operator!=(const Version &other) const noexcept { return !(*this == other); }

    inline bool operator>(const Version &other) const noexcept
    {
        if (major > other.major)
            return true;
        if (major < other.major)
            return false;
        return minor > other.minor;
    }

    inline bool operator<(const Version &other) const noexcept
    {
        if (major < other.major)
            return true;
        if (major > other.major)
            return false;
        return minor < other.minor;
    }

    inline bool operator>=(const Version &other) const noexcept { return (*this > other) || (*this == other); }

    inline bool operator<=(const Version &other) const noexcept { return (*this < other) || (*this == other); }

    unsigned int major;
    unsigned int minor;
};

}  // namespace ziapi
